@@ -11,6 +11,7 @@ from hdx.utilities.loader import load_yaml, load_json
 from hdx.utilities.path import script_dir_plus_file
 
 import hdx.data.dataset
+import hdx.data.filestore_helper
 from hdx.data.hdxobject import HDXObject, HDXError
 from hdx.data.resource_view import ResourceView
 from hdx.hdx_configuration import Configuration
@@ -119,7 +120,7 @@ class Resource(HDXObject):
         Returns:
             None
         """
-        self.data['format'] = file_type.lower()
+        self.data['format'] = file_type.upper()
 
     def get_file_to_upload(self):
         # type: () -> Optional[str]
@@ -161,7 +162,7 @@ class Resource(HDXObject):
                 raise HDXError('Either a url or a file to upload must be supplied!')
         else:
             if 'url' in self.data:
-                if self.data['url'] != hdx.data.dataset.Dataset.temporary_url:
+                if self.data['url'] != hdx.data.filestore_helper.FilestoreHelper.temporary_url:
                     raise HDXError('Either a url or a file to upload must be supplied not both!')
             if 'resource_type' not in self.data:
                 self.data['resource_type'] = 'file.upload'
@@ -198,24 +199,25 @@ class Resource(HDXObject):
         self._check_load_existing_object('resource', 'id')
         if self.file_to_upload and 'url' in self.data:
             del self.data['url']
-        self._merge_hdx_update('resource', 'id', self.file_to_upload, **kwargs)
+        self._merge_hdx_update('resource', 'id', self.file_to_upload, True, **kwargs)
 
-    def create_in_hdx(self):
-        # type: () -> None
+    def create_in_hdx(self, **kwargs):
+        # type: (Any) -> None
         """Check if resource exists in HDX and if so, update it, otherwise create it
 
         Returns:
             None
         """
-        self.check_required_fields()
+        if 'ignore_check' not in kwargs:  # allow ignoring of field checks
+            self.check_required_fields()
         id = self.data.get('id')
         if id and self._load_from_hdx('resource', id):
             logger.warning('%s exists. Updating %s' % ('resource', id))
             if self.file_to_upload and 'url' in self.data:
                 del self.data['url']
-            self._merge_hdx_update('resource', 'id', self.file_to_upload)
+            self._merge_hdx_update('resource', 'id', self.file_to_upload, True, **kwargs)
         else:
-            self._save_to_hdx('create', 'name', self.file_to_upload)
+            self._save_to_hdx('create', 'name', self.file_to_upload, True)
 
     def delete_from_hdx(self):
         # type: () -> None
